.. OutlierTree documentation master file, created by
   sphinx-quickstart on Mon Jul 15 21:32:28 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Explainable Outlier Detection
=============================

This is the documentation page for the python package *OutlierTree*. For 
more details, see the project's GitHub page:

`<https://www.github.com/david-cortes/outliertree>`_

Installation
=============================
Package is available on PyPI, can be installed with
::

    pip install outliertree

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodule:: outliertree
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
